Module analysis

Module analysis 

Facade over perl-semantic-analyzer for compatibility imports. Compatibility re-export of semantic analysis modules.

Modules

class_model
Semantic analysis, symbol extraction, and type inference. Class model for Moose/Moo/Mouse intelligence. Class model for Moose/Moo/Mouse/Class::Accessor intelligence.
declaration
Semantic analysis, symbol extraction, and type inference. Go-to-declaration support and parent map construction. Declaration Provider for LSP
export_analyzer
Semantic analysis, symbol extraction, and type inference. Export symbol extraction for Exporter-based Perl modules. Export symbol extraction for Exporter-based Perl modules
generated_member_extractor
Semantic analysis, symbol extraction, and type inference. Generated member extraction from Moo/Moose has declarations. Generated member extraction from Moo/Moose has declarations and Class::Accessor declarations.
import_extractor
Semantic analysis, symbol extraction, and type inference. Import specification extraction for static use statements. Import specification extractor for use and require statements.
index
Semantic analysis, symbol extraction, and type inference. Lightweight workspace symbol index. Cross-file workspace indexing for Perl symbols
package_graph_extractor
Semantic analysis, symbol extraction, and type inference. Package graph edge extraction from inheritance and role-composition patterns. Package graph edge extraction from Perl inheritance and role-composition patterns.
scope_analyzer
Semantic analysis, symbol extraction, and type inference. Scope analysis for variable and subroutine resolution. Scope analysis and variable tracking for Perl parsing workflows
semantic
Semantic analysis, symbol extraction, and type inference. Semantic analyzer and token classification. Semantic analysis for IDE features.
symbol
Semantic analysis, symbol extraction, and type inference. Symbol extraction and symbol table construction. Symbol extraction and symbol table for IDE features
type_inference
Semantic analysis, symbol extraction, and type inference. Type inference engine for Perl variable analysis.
value_shape_inferrer
Semantic analysis, symbol extraction, and type inference. Lightweight value-shape inference from constructor calls, bless, and $self. Lightweight value-shape inference from Perl AST patterns.