#[non_exhaustive]pub struct ExporterMetadata {
pub exports: Vec<ResolvedExport>,
pub export_ok: Vec<ResolvedExport>,
pub export_tags: HashMap<String, Vec<ResolvedExport>>,
pub unresolved: Vec<String>,
}Expand description
Exporter-derived metadata captured for a package in a single file.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.exports: Vec<ResolvedExport>Names exported by default via @EXPORT that resolve to local subs.
export_ok: Vec<ResolvedExport>Names available for explicit import via @EXPORT_OK that resolve to local subs.
%EXPORT_TAGS entries mapped to local subroutine definitions.
unresolved: Vec<String>Export names referenced in export declarations but not defined as local subs.