Module declaration

Module declaration 

Semantic analysis, symbol extraction, and type inference. Go-to-declaration support and parent map construction. Declaration Provider for LSP

Provides go-to-declaration functionality for finding where symbols are declared. Supports LocationLink for enhanced client experience.

Structs

DeclarationProvider
Provider for finding declarations in Perl source code.
LocationLink
Represents a location link from origin to target

Functions

current_package_at
Determines the current package context at the given offset.
find_node_at_offset
Finds the most specific AST node containing the given byte offset.
get_node_children
Returns direct child nodes for a given AST node.
symbol_at_cursor
Extracts a symbol key from the AST node at the given cursor position.

Type Aliases

ParentMap
Parent-map from child node to parent node, stored as raw pointers.