Module package_graph_extractor

Module package_graph_extractor 

Semantic analysis, symbol extraction, and type inference. Package graph edge extraction from inheritance and role-composition patterns. Package graph edge extraction from Perl inheritance and role-composition patterns.

Walks the AST to extract [PackageEdge] entries that describe inheritance, role composition, and dependency relationships between Perl packages.

Supported Patterns

Perl sourcePackageEdgeKind
use parent 'Base'Inherits
use parent qw(Base1 Base2)Inherits
use base 'Base'Inherits
use base qw(Base1 Base2)Inherits
@ISA = ('Base')Inherits
our @ISA = qw(Base1 Base2)Inherits
push @ISA, 'Base'Inherits
extends 'Base' (Moo/Moose)Inherits
with 'Role' (Moo/Moose)ComposesRole

Structs

PackageGraphExtractor
Extractor that walks an AST to produce PackageEdge entries for each inheritance, role-composition, or dependency relationship found.