#[non_exhaustive]pub enum ReceiverFallbackState {
Exact,
Fallback,
Blocked,
}Expand description
Fallback posture completion must preserve for this receiver fact.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exact
The receiver fact is exact enough to drive receiver-scoped completion.
Fallback
The receiver fact is not exact; completion must preserve legacy fallback.
Blocked
The receiver fact cannot participate in completion.