#[non_exhaustive]pub enum ShapeFact {
Hash(HashShape),
Array(ArrayShape),
Object(ObjectShape),
}Expand description
Structural shape metadata attached to a type fact.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Hash(HashShape)
Hash shape with known slots and optional fallback value.
Array(ArrayShape)
Array shape with known indexes and optional fallback element value.
Object(ObjectShape)
Object shape with known fields.