CodeAction

Struct CodeAction 

pub struct CodeAction {
    pub title: String,
    pub kind: CodeActionKind,
    pub diagnostics: Vec<String>,
    pub edit: CodeActionEdit,
    pub is_preferred: bool,
}
A code action that can be applied to fix an issue

Code actions represent automated fixes for common issues and refactoring operations that can be applied to Perl source code.

Fields

title: String

Human-readable title describing the action

kind: CodeActionKind

The kind/category of code action

diagnostics: Vec<String>

Diagnostic codes this action fixes

edit: CodeActionEdit

The edit operations to apply

is_preferred: bool

Whether this action is the preferred choice