pub struct CodeActionsProvider { /* private fields */ }Expand description
Code actions provider
Analyzes Perl source code and provides automated fixes and refactoring actions for common issues and improvement opportunities.
Implementations
Sourceimpl CodeActionsProvider
impl CodeActionsProvider
Sourcepub fn new(source: String) -> CodeActionsProvider
pub fn new(source: String) -> CodeActionsProvider
Create a new code actions provider
Sourcepub fn get_code_actions(
&self,
ast: &Node,
range: (usize, usize),
diagnostics: &[Diagnostic],
) -> Vec<CodeAction>
pub fn get_code_actions( &self, ast: &Node, range: (usize, usize), diagnostics: &[Diagnostic], ) -> Vec<CodeAction>
Get code actions for a range