pub fn get_operator_documentation(op: &str) -> Option<BuiltinDoc>Expand description
Get documentation for a Perl file test operator.
Returns signature and description for known file test operators,
or None if documentation is not available.
pub fn get_operator_documentation(op: &str) -> Option<BuiltinDoc>Get documentation for a Perl file test operator.
Returns signature and description for known file test operators,
or None if documentation is not available.