pub struct PragmaDoc {
pub summary: &'static str,
pub description: &'static str,
pub version_required: Option<&'static str>,
}Expand description
Documentation entry for a Perl pragma.
Provides a brief summary and description for display in hover tooltips
when a user hovers over a use strict;, use warnings;, etc. statement.
Fields
summary: &'static strOne-line purpose summary
description: &'static strDetailed description of what the pragma enables or does
version_required: Option<&'static str>Minimum Perl version required, if any (e.g. "v5.10")