#[non_exhaustive]pub struct PragmaMap { /* private fields */ }Expand description
Explicit pragma transition timeline.
Implementations
Sourceimpl PragmaMap
impl PragmaMap
Sourcepub fn snapshot_at(&self, offset: usize) -> PragmaSnapshot
pub fn snapshot_at(&self, offset: usize) -> PragmaSnapshot
Return the immutable snapshot active at the given byte offset.
Sourcepub fn state_at(&self, offset: usize) -> PragmaState
pub fn state_at(&self, offset: usize) -> PragmaState
Return the concrete pragma state active at the given byte offset.
Sourcepub fn final_state(&self) -> PragmaState
pub fn final_state(&self) -> PragmaState
Return the final top-level pragma state after all lexical restores.
Sourcepub fn cursor(&self) -> PragmaQueryCursor
pub fn cursor(&self) -> PragmaQueryCursor
Create a cursor for monotonic queries against this map.
Sourcepub fn entries(&self) -> &[PragmaEntry]
pub fn entries(&self) -> &[PragmaEntry]
Return all transition entries in source order.