Missing module detection (PL701) Missing module detection lint
Detects use Module statements where the module cannot be resolved
in the workspace or configured include paths.
Diagnostic codes
| Code | Severity | Description |
|---|---|---|
| PL701 | Warning | Module not found in include paths |
Constants
- CORE_
MODULES - Perl core modules that ship with every Perl installation.
Functions
- check_
missing_ modules - Check for use statements whose modules cannot be resolved.