Parser engine components and supporting utilities. Pragma tracker for Perl code analysis
Tracks use and no pragmas throughout the codebase to determine
effective pragma state at any point in the code.
Structs
- Compile
Time Pragma Environment - Explicit compile-time pragma environment that can answer file-position queries and expose immutable snapshots.
- Perl
Version - Parsed Perl version from a lexical
use v...;oruse 5.xxx;pragma. - Pragma
Query Cursor - Monotonic query cursor for repeated pragma lookups.
- Pragma
Snapshot - Immutable compile-time snapshot of pragma state.
- Pragma
State - Pragma state at a given point in the code
- Pragma
State Query - Query object describing compile-time pragma state at a byte offset.
- Pragma
Tracker - Tracks pragma state throughout a Perl file
Functions
- features_
enabled_ by_ version - Returns the language features implicitly enabled by declaring
use VERSION. - parse_
perl_ version - Parse a Perl version string into a major/minor pair.
- version_
implies_ strict - Whether
use VERSIONimpliesstrictfor this version. - version_
implies_ warnings - Whether
use VERSIONimplieswarningsfor this version.