pub fn features_enabled_by_version(version: PerlVersion) -> Vec<&'static str>Expand description
Returns the language features implicitly enabled by declaring use VERSION.
Mirrors the Perl feature pragma bundle semantics: each use vX.Y
declaration implicitly enables the same features as use feature ':X.Y'.
Features that were removed from a bundle (for example switch removed in
v5.36 and smartmatch removed in v5.42) are not included for that
version and above. Versions older than v5.10 load the :default bundle.