#[non_exhaustive]pub struct PragmaEntry {
pub range: Range<usize>,
pub snapshot: PragmaSnapshot,
}Expand description
One effective pragma-state transition over a source byte range.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.range: Range<usize>Source byte range covered by this snapshot.
Lexical scope restores are represented as zero-length ranges at the scope end so callers can observe the restored state at that byte offset.
snapshot: PragmaSnapshotImmutable pragma state active for this transition.