SemanticTokenType

Enum SemanticTokenType 

pub enum SemanticTokenType {
Show 21 variants Variable, VariableDeclaration, VariableReadonly, Parameter, Function, FunctionDeclaration, Method, Class, Namespace, Type, Keyword, KeywordControl, Modifier, Number, String, Regex, Comment, CommentDoc, Operator, Punctuation, Label,
}
Semantic analysis types for hover, tokens, and code understanding. Semantic token types for syntax highlighting in the Parse/Complete workflow.

Variants



Variable

Variable reference (scalar, array, or hash)



VariableDeclaration

Variable declaration site



VariableReadonly

Read-only variable (constant)



Parameter

Function parameter



Function

Function/subroutine reference



FunctionDeclaration

Function/subroutine declaration



Method

Object method call



Class

Class/package name



Namespace

Package namespace



Type

Type annotation (modern Perl)



Keyword

Language keyword (if, while, etc.)



KeywordControl

Control flow keyword (return, next, last)



Modifier

Variable modifier (my, our, local, state)



Number

Numeric literal



String

String literal



Regex

Regular expression



Comment

Regular comment



CommentDoc

Documentation comment (POD)



Operator

Operator (+, -, =~, etc.)



Punctuation

Punctuation marks and delimiters



Label

Code label for goto statements