Module error_recovery

Module error_recovery 

Error recovery strategies for resilient parsing. Error recovery strategies and traits for the Perl parser.

Structs

ParseError
Error information with recovery context for comprehensive Perl parsing error handling.

Enums

RecoveryResult
Result of a recovery operation.
SyncPoint
Synchronization tokens for error recovery

Traits

ErrorRecovery
Error recovery strategies
ParserErrorRecovery
Parser extensions for error recovery
StatementRecovery
Recovery-aware statement parsing