compute_links

Function compute_links 

pub fn compute_links(uri: &str, text: &str, _roots: &[Url]) -> Vec<Value>
Computes document links for a given Perl document.

This function scans the text for use and require statements and creates document links for them. Links are returned with a data field containing metadata for deferred resolution via documentLink/resolve.