Module incremental

Module incremental 

Incremental parsing for efficient re-parsing during editing.

Modules

incremental_advanced_reuse
Advanced tree reuse algorithms for incremental parsing
incremental_checkpoint
Incremental parser with lexer checkpointing
incremental_document
High-performance incremental document parsing with subtree reuse
incremental_edit
Enhanced edit structure for incremental parsing with text content
incremental_handler_v2
Incremental LSP didChange handler (deprecated).
incremental_integration
Integration module for incremental parsing with the main LSP server
incremental_simple
Simplified incremental parsing implementation
incremental_v2
Incremental parsing implementation with comprehensive tree reuse

Structs

Edit
Edit description
IncrementalState
LexCheckpoint
Stable restart points to avoid re-lexing the whole world
LineIndex
Line index for byte <-> (line, col) mapping.
ParseCheckpoint
Parse checkpoint with scope context
ReparseResult
Result of incremental reparse
ScopeSnapshot
Scope information at a parse checkpoint

Constants

MAX_EDIT_SIZE

Functions

apply_edits
Apply edits incrementally