IncrementalStats

Struct IncrementalStats 

pub struct IncrementalStats {
Show 15 fields pub total_parses: usize, pub incremental_parses: usize, pub tokens_reused: usize, pub tokens_relexed: usize, pub checkpoints_used: usize, pub cache_hits: usize, pub cache_misses: usize, pub left_checkpoint_distance: usize, pub right_checkpoint_distance: usize, pub bytes_relexed: usize, pub segments_reused_before: usize, pub segments_reused_after: usize, pub segments_invalidated: usize, pub full_tail_fallbacks: usize, pub tail_fallback_bytes: usize,
}
Statistics for incremental parsing

Fields

total_parses: usizeincremental_parses: usizetokens_reused: usizetokens_relexed: usizecheckpoints_used: usizecache_hits: usizecache_misses: usizeleft_checkpoint_distance: usize

Distance from edit start to the left checkpoint (in bytes)

right_checkpoint_distance: usize

Distance from edit end to the right checkpoint (in bytes)

bytes_relexed: usize

Total bytes relexed during incremental parsing

segments_reused_before: usize

Count of segments reused before the edit (cache efficiency metric)

segments_reused_after: usize

Count of segments reused after the edit (cache efficiency metric)

segments_invalidated: usize

Count of segments invalidated during edit (cache churn metric)

full_tail_fallbacks: usize

Count of times we had to relex the entire tail (cache coverage gaps)

tail_fallback_bytes: usize

Total bytes re-lexed while handling full tail fallbacks.