Integration module for incremental parsing with the main LSP server
This module provides the bridge between the existing LspServer and incremental parsing capabilities, controlled by feature flags.
Structs
- Incremental
Config - Configuration for incremental parsing
Enums
- Document
Parser - Wrapper for document state with incremental parsing support
Functions
- byte_
to_ lsp_ pos - Convert byte offset to LSP position using rope
- lsp_
change_ to_ edit - Helper to convert LSP ContentChange to IncrementalEdit
- lsp_
pos_ to_ byte - Convert LSP position to byte offset using rope