pub struct IncrementalState {
pub rope: Rope,
pub line_index: LineIndex,
pub lex_checkpoints: Vec<LexCheckpoint>,
pub parse_checkpoints: Vec<ParseCheckpoint>,
pub ast: Node,
pub tokens: Vec<Token>,
pub source: String,
}Expand description
Incremental parsing implementation and helpers. Incremental parsing state
Fields
rope: Ropeline_index: LineIndexlex_checkpoints: Vec<LexCheckpoint>parse_checkpoints: Vec<ParseCheckpoint>ast: Nodetokens: Vec<Token>source: StringImplementations
Sourceimpl IncrementalState
impl IncrementalState
pub fn new(source: String) -> IncrementalState
Sourcepub fn find_lex_checkpoint(&self, byte: usize) -> Option<&LexCheckpoint>
pub fn find_lex_checkpoint(&self, byte: usize) -> Option<&LexCheckpoint>
Find the best checkpoint before a given byte offset
Sourcepub fn find_parse_checkpoint(&self, byte: usize) -> Option<&ParseCheckpoint>
pub fn find_parse_checkpoint(&self, byte: usize) -> Option<&ParseCheckpoint>
Find the best parse checkpoint before a given byte offset