pub struct PerlModernizer { /* private fields */ }Expand description
Analyzer and transformer for modernizing Perl code.
Detects legacy Perl idioms and suggests modern replacements,
such as replacing bareword filehandles with lexical variables
or adding missing use strict and use warnings pragmas.
Implementations
Sourceimpl PerlModernizer
impl PerlModernizer
Sourcepub fn analyze(&self, code: &str) -> Vec<ModernizationSuggestion>
pub fn analyze(&self, code: &str) -> Vec<ModernizationSuggestion>
Analyzes Perl source code and returns modernization suggestions.
Checks for missing pragmas, bareword filehandles, deprecated patterns, indirect object notation, and other legacy idioms.