pub struct TextEdit {
pub start: usize,
pub end: usize,
pub new_text: String,
}Expand description
A single text edit within a file
Represents a single textual change within a document, defined by a byte range and the replacement text. The range is inclusive of the start position and exclusive of the end position.
Fields
start: usizeThe byte offset of the start of the range to replace (inclusive)
end: usizeThe byte offset of the end of the range to replace (exclusive)
new_text: StringThe text to replace the range with (may be empty for deletion)