get_builtin_documentation

Function get_builtin_documentation 

pub fn get_builtin_documentation(name: &str) -> Option<BuiltinDoc>
Get documentation for a Perl built-in function.

Returns signature and description for known built-in functions, or None if documentation is not available.

This is also used by the LSP hover handler to show builtin docs when the semantic analyzer has no symbol-level hit (e.g. bare-word builtins in fallback path).