pub struct PragmaTracker;Expand description
Pragma state tracking for use strict, use warnings, etc.
Tracks pragma state throughout a Perl file
Implementations
Sourceimpl PragmaTracker
impl PragmaTracker
Sourcepub fn build(ast: &Node) -> Vec<(Range<usize>, PragmaState)>
pub fn build(ast: &Node) -> Vec<(Range<usize>, PragmaState)>
Build a range-indexed pragma map from an AST
Sourcepub fn state_for_offset(
pragma_map: &[(Range<usize>, PragmaState)],
offset: usize,
) -> PragmaState
pub fn state_for_offset( pragma_map: &[(Range<usize>, PragmaState)], offset: usize, ) -> PragmaState
Get the pragma state at a specific byte offset