pub struct TriviaPreservingParser { /* private fields */ }Expand description
Parser that preserves trivia.
A parser that attaches comments and whitespace to AST nodes for formatting.
Implementations
Sourceimpl TriviaPreservingParser
impl TriviaPreservingParser
Sourcepub fn new(source: String) -> TriviaPreservingParser
pub fn new(source: String) -> TriviaPreservingParser
Create a new trivia-preserving parser
Sourcepub fn parse(self) -> NodeWithTrivia
pub fn parse(self) -> NodeWithTrivia
Parse and return AST with trivia preserved.
Returns a node with leading and trailing trivia attached.