Facade over perl-semantic-analyzer for compatibility imports.
Compatibility re-export of semantic analysis modules.
Modules
- class_
model - Semantic analysis, symbol extraction, and type inference. Class model for Moose/Moo/Mouse intelligence. Class model for Moose/Moo/Mouse/Class::Accessor intelligence.
- declaration
- Semantic analysis, symbol extraction, and type inference. Go-to-declaration support and parent map construction. Declaration Provider for LSP
- export_
analyzer - Semantic analysis, symbol extraction, and type inference. Export symbol extraction for Exporter-based Perl modules. Export symbol extraction for Exporter-based Perl modules
- generated_
member_ extractor - Semantic analysis, symbol extraction, and type inference.
Generated member extraction from Moo/Moose
hasdeclarations. Generated member extraction from Moo/Moosehasdeclarations andClass::Accessordeclarations. - import_
extractor - Semantic analysis, symbol extraction, and type inference.
Import specification extraction for static
usestatements. Import specification extractor foruseandrequirestatements. - index
- Semantic analysis, symbol extraction, and type inference. Lightweight workspace symbol index. Cross-file workspace indexing for Perl symbols
- package_
graph_ extractor - Semantic analysis, symbol extraction, and type inference. Package graph edge extraction from inheritance and role-composition patterns. Package graph edge extraction from Perl inheritance and role-composition patterns.
- scope_
analyzer - Semantic analysis, symbol extraction, and type inference. Scope analysis for variable and subroutine resolution. Scope analysis and variable tracking for Perl parsing workflows
- semantic
- Semantic analysis, symbol extraction, and type inference. Semantic analyzer and token classification. Semantic analysis for IDE features.
- symbol
- Semantic analysis, symbol extraction, and type inference. Symbol extraction and symbol table construction. Symbol extraction and symbol table for IDE features
- type_
inference - Semantic analysis, symbol extraction, and type inference. Type inference engine for Perl variable analysis.
- value_
shape_ inferrer - Semantic analysis, symbol extraction, and type inference.
Lightweight value-shape inference from constructor calls, bless, and
$self. Lightweight value-shape inference from Perl AST patterns.