#[non_exhaustive]pub struct ReceiverFact {
pub kind: ReceiverKind,
pub package: Option<String>,
pub shape: Option<ShapeFact>,
pub confidence: Confidence,
pub evidence: Vec<TypeEvidence>,
pub freshness: ReceiverFactFreshness,
pub dynamic_boundary: Option<DynamicBoundary>,
pub source_range: Option<(usize, usize)>,
pub fallback_state: ReceiverFallbackState,
}Expand description
Trust-bounded evidence about a method-call receiver.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: ReceiverKindClassified receiver kind.
package: Option<String>Inferred package for method ranking, when available.
shape: Option<ShapeFact>Structural shape fact associated with the receiver, when available.
confidence: ConfidenceConfidence assigned to this receiver fact.
evidence: Vec<TypeEvidence>Evidence used to classify the receiver.
freshness: ReceiverFactFreshnessFreshness of the receiver evidence.
dynamic_boundary: Option<DynamicBoundary>Dynamic boundary that prevents precise method completion, when present.
source_range: Option<(usize, usize)>Source-backed byte range for the receiver expression.
fallback_state: ReceiverFallbackStateFallback posture completion must preserve for this receiver.