Parser engine components and supporting utilities. Edit tracking for incremental parsing
This module provides types and algorithms for tracking edits to source code and applying them to an existing parse tree.
Parser engine components and supporting utilities. Edit tracking for incremental parsing
This module provides types and algorithms for tracking edits to source code and applying them to an existing parse tree.