Crate pragma_tracker

Crate pragma_tracker 

Parser engine components and supporting utilities. Pragma tracker for Perl code analysis

Tracks use and no pragmas throughout the codebase to determine effective pragma state at any point in the code.

Structs

PragmaState
Pragma state at a given point in the code
PragmaTracker
Tracks pragma state throughout a Perl file