Parser engine components and supporting utilities. Pragma tracker for Perl code analysis
Tracks use and no pragmas throughout the codebase to determine
effective pragma state at any point in the code.
Structs
- Pragma
State - Pragma state at a given point in the code
- Pragma
Tracker - Tracks pragma state throughout a Perl file