features_enabled_by_version

Function features_enabled_by_version 

pub fn features_enabled_by_version(version: PerlVersion) -> Vec<&'static str>
Returns the language features implicitly enabled by declaring use VERSION.

Mirrors the Perl feature pragma bundle semantics: each use vX.Y declaration implicitly enables the same features as use feature ':X.Y'. Features that were removed from a bundle (e.g. switch removed in v5.38) are not included for that version and above.

Reference: https://perldoc.perl.org/feature#FEATURE-BUNDLES