Incremental parsing for efficient re-parsing during editing.
Modules
- incremental_
advanced_ reuse - Advanced tree reuse algorithms for incremental parsing
- incremental_
checkpoint - Incremental parser with lexer checkpointing
- incremental_
document - High-performance incremental document parsing with subtree reuse
- incremental_
edit - Enhanced edit structure for incremental parsing with text content
- incremental_
handler_ v2 - Incremental LSP didChange handler (deprecated).
- incremental_
integration - Integration module for incremental parsing with the main LSP server
- incremental_
simple - Simplified incremental parsing implementation
- incremental_
v2 - Incremental parsing implementation with comprehensive tree reuse
Structs
- Edit
- Edit description
- Incremental
State - LexCheckpoint
- Stable restart points to avoid re-lexing the whole world
- Line
Index - Line index for byte <-> (line, col) mapping.
- Parse
Checkpoint - Parse checkpoint with scope context
- Reparse
Result - Result of incremental reparse
- Scope
Snapshot - Scope information at a parse checkpoint
Constants
Functions
- apply_
edits - Apply edits incrementally