Module incremental

Module incremental 

Incremental parsing for efficient re-parsing during editing. Compatibility re-export of incremental parsing modules.

Modules

incremental_advanced_reuse
Incremental parsing implementation and helpers. Advanced tree reuse algorithms for incremental parsing
incremental_checkpoint
Incremental parsing implementation and helpers. Incremental parser with lexer checkpointing
incremental_document
Incremental parsing implementation and helpers. High-performance incremental document parsing with subtree reuse
incremental_edit
Incremental parsing implementation and helpers. Enhanced edit structure for incremental parsing with text content
incremental_handler_v2
Incremental parsing implementation and helpers. Incremental LSP didChange handler (deprecated).
incremental_integration
Incremental parsing implementation and helpers. Integration module for incremental parsing with the main LSP server
incremental_simple
Incremental parsing implementation and helpers. Simplified incremental parsing implementation
incremental_v2
Incremental parsing implementation and helpers. Incremental parsing implementation with comprehensive tree reuse

Structs

Edit
Incremental parsing implementation and helpers. Edit description
IncrementalState
Incremental parsing implementation and helpers. Incremental parsing state
LexCheckpoint
Incremental parsing implementation and helpers. Stable restart points to avoid re-lexing the whole world
LineIndex
Incremental parsing implementation and helpers. Line index for byte <-> (line, col) mapping.
ParseCheckpoint
Incremental parsing implementation and helpers. Parse checkpoint with scope context
ReparseResult
Incremental parsing implementation and helpers. Result of incremental reparse
ScopeSnapshot
Incremental parsing implementation and helpers. Scope information at a parse checkpoint

Functions

apply_edits
Incremental parsing implementation and helpers. Apply edits incrementally