pub struct IncrementalStats {Show 15 fields
pub total_parses: usize,
pub incremental_parses: usize,
pub tokens_reused: usize,
pub tokens_relexed: usize,
pub checkpoints_used: usize,
pub cache_hits: usize,
pub cache_misses: usize,
pub left_checkpoint_distance: usize,
pub right_checkpoint_distance: usize,
pub bytes_relexed: usize,
pub segments_reused_before: usize,
pub segments_reused_after: usize,
pub segments_invalidated: usize,
pub full_tail_fallbacks: usize,
pub tail_fallback_bytes: usize,
}Expand description
Statistics for incremental parsing
Fields
total_parses: usizeincremental_parses: usizetokens_reused: usizetokens_relexed: usizecheckpoints_used: usizecache_hits: usizecache_misses: usizeleft_checkpoint_distance: usizeDistance from edit start to the left checkpoint (in bytes)
right_checkpoint_distance: usizeDistance from edit end to the right checkpoint (in bytes)
bytes_relexed: usizeTotal bytes relexed during incremental parsing
segments_reused_before: usizeCount of segments reused before the edit (cache efficiency metric)
segments_reused_after: usizeCount of segments reused after the edit (cache efficiency metric)
segments_invalidated: usizeCount of segments invalidated during edit (cache churn metric)
full_tail_fallbacks: usizeCount of times we had to relex the entire tail (cache coverage gaps)
tail_fallback_bytes: usizeTotal bytes re-lexed while handling full tail fallbacks.