LineIndex

Struct LineIndex 

pub struct LineIndex { /* private fields */ }
Line index for byte <-> (line, col) mapping.

Implementations

Source

impl LineIndex

pub fn new(text: &str) -> LineIndex

Build a line index from UTF-8 text.

pub fn byte_to_position(&self, byte: usize) -> (usize, usize)

Convert a byte offset to (line, column) using byte columns.

pub fn position_to_byte(&self, line: usize, column: usize) -> Option<usize>

Convert (line, column) back to byte offset.

Returns None when the line is out of range or when the column extends past the end of the line (including the newline character, but not the start of the next line).

pub fn position_to_byte_checked( &self, line: usize, column: usize, ) -> Option<usize>

Convert (line, column) back to byte offset, returning None when the column crosses the line boundary.

The newline character at the end of a line is the last addressable column on that line. The byte at next_line_start belongs to the next line and is therefore out of range.