pub struct FileEdit {
pub file_path: PathBuf,
pub edits: Vec<TextEdit>,
}Expand description
A file edit as part of a refactoring operation
Represents a set of text edits that should be applied to a single file as part of a workspace refactoring operation. All edits within a FileEdit are applied to the same file and should be applied in reverse order (from end to beginning) to maintain position validity.
Fields
file_path: PathBufThe absolute path to the file that should be edited
edits: Vec<TextEdit>The list of text edits to apply to this file, in document order