Parser utilities and helpers. Utility functions for the Perl parser
Functions
- code_
slice - Helper to get the code portion of text (before DATA/END)
- find_
data_ marker_ byte Deprecated - Find the byte offset of a DATA or END marker in the source text. Returns the byte offset of the start of the marker line, or None if not found.
- find_
data_ marker_ byte_ lexed - Find the byte offset of a DATA or END marker in the source text. Uses the lexer to avoid false positives in heredocs/POD. Returns the byte offset of the start of the marker, or None if not found.