EstimateSize

Trait EstimateSize 

pub trait EstimateSize {
    // Required method
    fn estimate_size(&self) -> usize;
}
Trait for estimating the memory size of cached values.

Implement this trait for custom types to enable accurate memory tracking.

Required Methods

fn estimate_size(&self) -> usize

Estimate the memory size of this value in bytes.

Implementations on Foreign Types

Source

impl EstimateSize for str

Source

impl EstimateSize for ()

Source

impl EstimateSize for String

Source

impl EstimateSize for [u8]

Source

impl<K, V> EstimateSize for HashMap<K, V>

Source

impl<T> EstimateSize for Option<T>
where T: EstimateSize,

Source

impl<T> EstimateSize for &T
where T: EstimateSize + ?Sized,

Source

impl<T> EstimateSize for Vec<T>
where T: EstimateSize,

Source

impl<T, E> EstimateSize for Result<T, E>

Implementors