pub trait EstimateSize {
// Required method
fn estimate_size(&self) -> usize;
}Expand description
Trait for estimating the memory size of cached values.
Implement this trait for custom types to enable accurate memory tracking.
Required Methods
Sourcefn estimate_size(&self) -> usize
fn estimate_size(&self) -> usize
Estimate the memory size of this value in bytes.